<?php
/*
This module shows how to load a list from a custom database table.
The list can be drop-down list or a multi-select list box in your form.
You can load any number of lists using a single module. 
Note that this module is advanced. You should have some programming experience and some 
database familiarity to adapt this module to your needs.

### Steps
Add the drop-down lists in your form. Enable the 'Load from database' feature in its properties. 

Edit and update the module. Update the database login details.

Customize the table names, the list names and the field names according  to your database schema. Use the logging feature to troubleshoot.

*/
class MyListLoader extends FM_ExtensionModule
{
	private $conn;

	/*
		Login to the mysql database.
		Remember to enter the correct DB login details.

		Enable logging in Simfatic Forms if you want to troubleshoot.

	*/
	private function dbLogin()
	{
		//Update the Database details here.
		$servername = "localhost";
		$username = "user10";
		$password = "user10";
		$dbname = "user10";

		// Create connection
		$this->conn = new mysqli($servername, $username, $password, $dbname);
		$this->logger->LogInfo("MyListLoader: Connecting to DB ...");
		// Check connection
		if ($$this->conn->connect_error) 
		{
		    $this->logger->LogError('MyListLoader: Error logging in to the db');
		    return false;
		} 		
		$this->logger->LogInfo("MyListLoader: DB Connected ...");
		return true;
	}

  /*
  		Simfatic Forms calls LoadDynamicList() to fill each list that is 
  		loaded from database. 
  		$listname is the name of the list that you assigned in Simfatic Forms "Draw the form" page.
  		if you return true, the list in the list_rows is used
  		If you return false, Simfatic Forms loads its default list that you created in 
  		the "Draw the form" page.
   */
   public function LoadDynamicList($listname,&$list_rows)
   {
   		if($listname == 'product')
   		{
	    	return $this->loadProductList($list_rows);
   		}
   		elseif($listname == 'categories' )
   		{
   			return $this->loadCategoryList($list_rows);
   		}
   		/*
   		Follow the same pattern to load more lists
   		*/
   		return false;
   }

   private function loadProductList(&$list_rows)
   {
   		if(!$this->dbLogin())
		{
			//Error logging in to the Database
			return false;
		}

		$result = $this->conn->query("SELECT name FROM products");
		$list_rows = array();

		/*
			The list is to be loaded in this format:
			each item should have a name and a value. 
			[
				[ 'name'=>'item 1', 'value'=>'Item 1 Value' ],
				[ 'name'=>'item 2', 'value'=>'Item 2 Value' ],
				[ 'name'=>'item 3', 'value'=>'Item 3 Value' ]
			]
		*/

		//add the first& default item
		$list_rows[] = array('name'=>'Select ...','value'=>'');

		while($db_row = $result->fetch_assoc()) 
		{
			// we will keep the name and value the same.
			// the column name in the database is 'name'
			//if your database column is different, just use that.
			// example: 'name'=>$db_row['desc']
			$list_rows[]= array( 'name'=>$db_row['name'],
				                 'value'=>$db_row['name']);
    	}
    	$this->logger->LogInfo("MyListLoader: loaded the product list ");   	

    	return true;
   }

   private function loadCategoryList(&$list_rows)
   {
   		if(!$this->dbLogin())
		{
			//Error logging in to the Database
			return false;
		}

		$result = $this->conn->query("SELECT name FROM categories");
		$list_rows = array();
		
		//add the first& default item
		$list_rows[] = array('name'=>'Select ...',value=>'');

		while($db_row = $result->fetch_assoc()) 
		{
			$list_rows[]= array('name'=>$db_row['cat_name'],'value'=>$db_row['cat_name']);
    	}
    	$this->logger->LogInfo("MyListLoader: loaded the category list ");   	

    	return true;
   }
}

